/*

File: example.cpp

An example of the use of the GHexomino class.
Reminder: This is a toy implementation, created
to aid in understanding how the system works.

This example generates a set of points for a 
constant-value function.

Usage: example [magnitude_factor]
								by default, magnitude_factor = 1534

 This is a toy (non-optimized) implementation of the importance sampling
 technique proposed in the paper:
 "Polyomino-Based Digital Halfotning", by Victor Ostromoukhov,
 presented at SIGGRAPH 2007.

 Implementation by Victor Ostromoukhov
 Universite de Montreal 2007

*/

#include <iostream>
#include "GHexomino_prototype.h"


class MyGHexomino : public GHexomino
{
  unsigned const_val;

public:
  MyGHexomino(unsigned val) : GHexomino(4,4), const_val(val) {}

  unsigned getImportanceAt( Point2D pt ) 
  { 
    return const_val; // This function returns a constant value.
  }
};


typedef std::vector<Point2D> PointList;

int main(int argc, char* argv[])
{
  unsigned mag_factor = 1534; // outputs 1024 pts within unit square

  if (argc>1) mag_factor = atoi(argv[1]);

  // initialize sampler
  MyGHexomino test(mag_factor);

  // generate points
  PointList points = test.getSamplingPoints();

  // print points
  for ( PointList::iterator it=points.begin(); it!=points.end(); it++ )
    std::cout << it->x << " " << it->y << std::endl;

  return 0;
}

